==> haskell-turtle-1.6.2-106-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 turtle
version:              1.6.2
visibility:           public
id:                   turtle-1.6.2-BjRvCrMyzIKGHFGimeycp
key:                  turtle-1.6.2-BjRvCrMyzIKGHFGimeycp
license:              BSD-3-Clause
copyright:            2015 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  d09979dbe309b1bc2d00d327d780d758
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-turtle
hs-libraries:         HSturtle-1.6.2-BjRvCrMyzIKGHFGimeycp
depends:
    ansi-wl-pprint-1.0.2-9VhTQv6Iri66hFWSIMsCBh
    async-2.2.5-75FFlJsh5XPALDlYx1XYqh base-4.17.2.1
    bytestring-0.11.5.3 clock-0.8.4-Kiu8i6blCSFKOwrtBUKFnd
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 foldl-1.4.18-Jkj2M3vW7eJ9gVBhArF8ZW
    hostname-1.0-LeTF2MpavibDHBTJAkCOwY
    managed-1.0.10-CrvLNY2sLDT8jZhIlothny
    optional-args-1.0.2-3D00KgSuB6i2d4bFhkB0pW
    optparse-applicative-0.18.1.0-1qQAtHv6qKDHnowaperQhI
    process-1.6.18.0 stm-2.5.1.0
    streaming-commons-0.2.3.0-5jTPiK02A7aAdfEK1mMMP9
    temporary-1.3-IbENfV52re6K6jELI02KCQ text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4-EMY80kE8QWvCO803nZuJ6g

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-turtle-1.6.2-107-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-turtle.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 turtle
version:              1.6.2
visibility:           public
id:                   turtle-1.6.2-GBHyx1nKs1V17yvoDn0z1L
key:                  turtle-1.6.2-GBHyx1nKs1V17yvoDn0z1L
license:              BSD-3-Clause
copyright:            2015 Gabriella Gonzalez
maintainer:           GenuineGabriella@gmail.com
author:               Gabriella Gonzalez
synopsis:             Shell programming, Haskell-style
description:
    @turtle@ is a reimplementation of the Unix command line environment
    in Haskell so that you can use Haskell as both a shell and a scripting
    language.

    Features include:

    * Batteries included: Command an extended suite of predefined utilities

    * Interoperability: You can still run external shell commands

    * Portability: Works on Windows, OS X, and Linux

    * Exception safety: Safely acquire and release resources

    * Streaming: Transform or fold command output in constant space

    * Patterns: Use typed regular expressions that can parse structured values

    * Formatting: Type-safe @printf@-style text formatting

    * Modern: Supports @text@

    Read "Turtle.Tutorial" for a detailed tutorial or "Turtle.Prelude" for a
    quick-start guide

    @turtle@ is designed to be beginner-friendly, but as a result lacks certain
    features, like tracing commands.  If you feel comfortable using @turtle@
    then you should also check out the @Shelly@ library which provides similar
    functionality.

category:             System
abi:                  5832b97c757ca80534d896d2f58d0c01
exposed:              True
exposed-modules:
    Turtle Turtle.Bytes Turtle.Format Turtle.Line Turtle.Options
    Turtle.Pattern Turtle.Prelude Turtle.Shell Turtle.Tutorial

hidden-modules:       Turtle.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/turtle-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-turtle
hs-libraries:         HSturtle-1.6.2-GBHyx1nKs1V17yvoDn0z1L
depends:
    ansi-wl-pprint-1.0.2-4PXrdF4oCM6KBTLkiOpQHY
    async-2.2.5-Fwc3ABGHG7o8WWC3l3QDRi base-4.17.2.1
    bytestring-0.11.5.3 clock-0.8.4-54ET3pulaKB2uq0BWVwRr
    containers-0.6.7 directory-1.3.7.1 exceptions-0.10.5
    filepath-1.4.2.2 foldl-1.4.18-BhUx08dpHqjGR9NmnEqPeB
    hostname-1.0-LeTF2MpavibDHBTJAkCOwY
    managed-1.0.10-CrvLNY2sLDT8jZhIlothny
    optional-args-1.0.2-3D00KgSuB6i2d4bFhkB0pW
    optparse-applicative-0.18.1.0-B5S7p3yvcpkHKfw0kuCuBU
    process-1.6.18.0 stm-2.5.1.0
    streaming-commons-0.2.3.0-q2ZN2jYU5KLmG1DmYZNkR
    temporary-1.3-836zY2cPz8HAaBXH2WMEd1 text-2.0.2 time-1.12.2
    transformers-0.5.6.2 unix-2.7.3
    unix-compat-0.7.4-F45C0yQb72PB0noYxmBbjG

haddock-interfaces:   /usr/share/doc/haskell-turtle/html/turtle.haddock
haddock-html:         /usr/share/doc/haskell-turtle/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
